package jalview.io;

import jalview.gui.AlignFrame;
import jalview.schemes.ColourSchemeI;

import java.io.IOException;

import org.jsoup.Jsoup;
import org.jsoup.nodes.Document;
import org.jsoup.nodes.Element;

public class HtmlFile extends AlignFile
{
  public static final String FILE_EXT = "html";

  public static final String FILE_DESC = "HTML";

  private ColourSchemeI colourScheme;

  private boolean showSeqFeatures;

  public HtmlFile()
  {
    super();
  }

  public HtmlFile(FileParse source) throws IOException
  {
    super(source);
  }

  public HtmlFile(String inFile, String type) throws IOException
  {
    super(inFile, type);
  }

  @Override
  public void parse() throws IOException
  {
    try
    {
      StringBuilder htmlData = new StringBuilder();
      String currentLine;
      while ((currentLine = nextLine()) != null)
      {
        htmlData.append(currentLine);
      }

      Document doc = Jsoup.parse(htmlData.toString());
      Element content = doc.getElementById("seqData");
      String alignmentJsonString = content.val();

      JSONFile jsonFile = new JSONFile().parse(alignmentJsonString);
      seqs = jsonFile.seqs;
      seqGroups = jsonFile.seqGroups;
      annotations = jsonFile.annotations;
      showSeqFeatures = jsonFile.isShowSeqFeatures();
      colourScheme = jsonFile.getColourScheme();
    } catch (Exception e)
    {
      e.printStackTrace();
    }
  }

  public void applySettingsToAlignFrame(AlignFrame af)
  {
    af.setShowSeqFeatures(isShowSeqFeatures());
    af.changeColour(getColourScheme());
    af.setMenusForViewport();
  }


  @Override
  public String print()
  {
    throw new UnsupportedOperationException(
            "Print method of HtmlFile is not supported!");
  }

  public boolean isShowSeqFeatures()
  {
    return showSeqFeatures;
  }

  public void setShowSeqFeatures(boolean showSeqFeatures)
  {
    this.showSeqFeatures = showSeqFeatures;
  }

  public ColourSchemeI getColourScheme()
  {
    return colourScheme;
  }

  public void setColourScheme(ColourSchemeI colourScheme)
  {
    this.colourScheme = colourScheme;
  }

}
